#include "common.h"
#include "window_main.h"

#define UPDATE_FILE "/usr/share/system-update/update-package"
#define AUTO_UPDATE_FLAG	"/usr/share/system-update/auto-update-flag"

extern GtkWidget *auto_update_window;
extern GtkWidget *manual_update_window;
extern GtkWidget *patch_update_window;

//显示子窗口
void show_auto_window(GtkWidget *widget)
{
	GtkWidget *dialog;

	if (file_empty(UPDATE_FILE))
	{
		dialog = gtk_message_dialog_new(GTK_WINDOW (auto_update_window),
				GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
				GTK_MESSAGE_INFO,
				GTK_BUTTONS_OK,
				"当前已是最新系统！");
		gtk_dialog_run (GTK_DIALOG (dialog));
		gtk_widget_destroy (dialog);

		return ;
	}


	gtk_widget_show_all(auto_update_window);
}

void show_manual_window(GtkWidget *widget)
{
	GtkWidget *dialog;

	if (file_empty(UPDATE_FILE) || !access(AUTO_UPDATE_FLAG, F_OK))
	{
		dialog = gtk_message_dialog_new(GTK_WINDOW (auto_update_window),
				GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
				GTK_MESSAGE_INFO,
				GTK_BUTTONS_OK,
				"当前已是最新系统！");
		gtk_dialog_run (GTK_DIALOG (dialog));
		gtk_widget_destroy (dialog);

		return ;
	}


	gtk_widget_show_all(manual_update_window);
}

void show_patch_window(GtkWidget *widget)
{
	gtk_widget_show_all(patch_update_window);
}

//隐藏子窗口
void hide_test_window(GtkWidget *widget)
{
	gtk_widget_hide_all(auto_update_window);
}


GtkWidget *create_main_window()
{//创建主窗口
	GtkWidget *window;
	GtkWidget *vbox;            //盒装容器
	GtkWidget *menubar;         //菜单栏
	//GtkWidget *menu_about, *menu_about_us;  //帮助菜单
	GtkWidget *toolbar;         //工具栏
	GtkToolItem *tool_exit, *tool_sep;
	GtkWidget *statusbar;       //状态栏
	GtkWidget *fixed;

	GtkWidget *label;
	GtkWidget *system_version;

	GtkWidget *auto_button;
	GtkWidget *manual_button;
	GtkWidget *patch_button;

	window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_window_set_title(GTK_WINDOW(window), "系统更新");
	gtk_window_set_default_size(GTK_WINDOW(window), 500, 400);
	gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);

	/*函数gtk_window_set_icon() 是为窗口设置图标用的，函数create_pixbuf是我们自定义的，目的是从一个图片中获取信息得到pixbuf。*/
	gtk_window_set_icon(GTK_WINDOW(window), create_pixbuf("/usr/share/system-update/system-logo-icon.png"));

	/*创建一个盒装容器并添加到窗口中*/
	vbox = gtk_vbox_new(FALSE, 0);
	gtk_container_add(GTK_CONTAINER(window), vbox);

	/*创建菜单*/
	menubar = gtk_menu_bar_new();   //代表整个菜单,是一个menu shell

	//创建工具栏
	toolbar = gtk_toolbar_new();
	gtk_toolbar_set_style(GTK_TOOLBAR(toolbar), GTK_TOOLBAR_ICONS); //设置工具栏样式为图标
	gtk_container_set_border_width(GTK_CONTAINER(toolbar), 0);      //工具栏边框大小


	tool_sep = gtk_separator_tool_item_new();                       //工具栏中按钮之间的分割线
	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), tool_sep, -1);


	statusbar = gtk_statusbar_new();
	fixed = gtk_fixed_new();
	/*把菜单加入盒子容器*/
//	gtk_box_pack_start(GTK_BOX(vbox), menubar, FALSE, FALSE, 1);
	/*把工具栏加入盒子容器*/
//	gtk_box_pack_start(GTK_BOX(vbox), toolbar, FALSE, FALSE, 0);
	/*把fixed加入主工作区*/
	gtk_box_pack_start(GTK_BOX(vbox), fixed, FALSE, FALSE, 0);

	/*在fixed中放入一些按钮和label*/
	auto_button = gtk_button_new_with_label("自动更新");
	gtk_fixed_put(GTK_FIXED(fixed), auto_button, 20, 450);
	gtk_widget_set_size_request(auto_button, 100, 50);

	manual_button = gtk_button_new_with_label("手动更新");
	gtk_fixed_put(GTK_FIXED(fixed), manual_button, 250, 450);
	gtk_widget_set_size_request(manual_button, 100, 50);

	patch_button = gtk_button_new_with_label("补丁更新");
	gtk_fixed_put(GTK_FIXED(fixed), patch_button, 500,450);
	gtk_widget_set_size_request(patch_button, 100, 50);


	label = gtk_label_new("当前系统版本：");
	gtk_fixed_put(GTK_FIXED(fixed), label, 60, 40);
	gtk_widget_set_size_request(label, 100, 50);

	system_version = gtk_label_new("Loongson-Desktop-20");
	gtk_fixed_put(GTK_FIXED(fixed), system_version, 60, 60);
	gtk_widget_set_size_request(system_version, 160, 70);

    GtkWidget *image_one = gtk_image_new_from_file("/usr/share/system-update/logo.png");
	gtk_fixed_put(GTK_FIXED(fixed), image_one, 140, 120);
	gtk_widget_set_size_request(image_one, 320, 280);



	/*把状态栏加入盒子最下面*/
	gtk_box_pack_end(GTK_BOX(vbox), statusbar, FALSE, TRUE, 1);

	/*关闭窗口时退出主循环*/
	g_signal_connect_swapped(G_OBJECT(window),"destroy",G_CALLBACK(gtk_main_quit), NULL);

	g_signal_connect(G_OBJECT(auto_button), "clicked",G_CALLBACK(show_auto_window), NULL);
	g_signal_connect(G_OBJECT(manual_button), "clicked",G_CALLBACK(show_manual_window), NULL);
	g_signal_connect(G_OBJECT(patch_button), "clicked",G_CALLBACK(show_patch_window), NULL);


	return window;


}
